@@ -35,6 +35,36 @@ my $pwd = "/var/lib/sitesummary/entries";  # Path to the entries
 # File for debian-edu configuration
 my $debian_edu_config = "/debian-edu/config";
 
+# Provide mechanism to remap host names for hosts private networks
+# available via tunnels.
+
+my $hostmapfile = "/etc/sitesummary/hostmap";
+my $hostmapdir = "/etc/sitesummary/hostmap.d";
+my %hostmap;
+
+sub load_hostmap {
+    my @files = ($hostmapfile);
+    %hostmap = (); # Clear hostmap
+
+    if (opendir(my $dh, $hostmapdir)) {
+        push(@files, grep { /^\./ && -f "$some_dir/$_" } sort readdir($dh));
+        closedir $dh;
+    }
+    for my $file (@files) {
+        if (open(my $fh, '<', $file)) {
+            while (<$fh>) {
+                chomp;
+                s/\#.*$//;
+                next if m/^\s*$/;
+                my ($hostid, $newhostname) = split(/\s+/);
+                $hostmap{$hostid} = $newhostname;
+            }
+            close $fh;
+        }
+    }
+    return;
+}
+
 sub get_filepath_current {
     my ($hostid, $file) = @_;
     return "$pwd/$hostid$file";
@@ -172,7 +202,11 @@ sub get_primary_macaddress {
 #
 sub get_hostname {
     my $hostid = shift;
-    return get_file_string($hostid, "/system/hostname");
+    if (exists $hostmap{$hostid}) {
+        return $hostmap{$hostid};
+    } else {
+        return get_file_string($hostid, "/system/hostname");
+    }
 }
 
 #
@@ -289,6 +323,8 @@ sub get_hardware_info {
                            "Not Specified" eq $vendor
                            || "System Manufaturer" eq $vendor
                            || "System manufaturer" eq $vendor
+                           || "System manufacturer" eq $vendor
+                           || "To Be Filled By O.E.M." eq $vendor
                            || "To Be Filled By O.E.M. by More String" eq $vendor
                           ));
         undef $model if (defined $model &&
@@ -296,6 +332,7 @@ sub get_hardware_info {
                           "Not Specified" eq $model
                           || "System Name" eq $model
                           || "System Product Name" eq $model
+                          || "To Be Filled By O.E.M." eq $model
                           || "To Be Filled By O.E.M. To Be Filled By O.E.M." eq $model
                          ));
 
@@ -305,6 +342,7 @@ sub get_hardware_info {
                                        && $version ne "Not Specified"
                                        && $version ne "Not Available"
                                        && $version ne "System Version"
+                                       && $version ne "To Be Filled By O.E.M."
                                        && $version ne "None");
 
         return ($vendor, $model, $serial);
@@ -385,6 +423,7 @@ sub get_age_group {
     return $thisgroup;
 }
 
+load_hostmap();
 1;
 
 ########################################################################
